# CHANGELOG


## v0.1.3 (2025-05-12)

### Build System

- Added maturin to development dependencies
  ([`5e58e2b`](https://github.com/mpasson/REMSOL/commit/5e58e2ba989e84374195934ad13eed6993352293))

- Updated rust dependencies
  ([`bc69660`](https://github.com/mpasson/REMSOL/commit/bc69660e463bd253d5151a3b8e6d8817e995bd1a))


## v0.1.2 (2025-05-12)

### Bug Fixes

- Improved zero finding strategy
  ([`bd80d8c`](https://github.com/mpasson/REMSOL/commit/bd80d8cc8a38747c8c7b62b5a2846ee645c99663))

### Build System

- Added semantic release to dev dependencies
  ([`eb94ee1`](https://github.com/mpasson/REMSOL/commit/eb94ee13b7f9610722d318521fd38021a0dd89f9))

- Added semantic-release setting to update version in Cargo.toml
  ([`cee740e`](https://github.com/mpasson/REMSOL/commit/cee740e37aefd70f17dc4bd164bdc27b4cc2fdd2))

- Updated uv.lock
  ([`998a9da`](https://github.com/mpasson/REMSOL/commit/998a9da4f1001ba5afaf4e2c4f59f2957234f0bc))

### Refactoring

- Removed clippy warnings from scattering_matrix.rs and transfer_matrix.rs
  ([`245145f`](https://github.com/mpasson/REMSOL/commit/245145fcf0bb6913cc8c0bf51967302a573e9088))

- Removed non used bin files
  ([`bc00450`](https://github.com/mpasson/REMSOL/commit/bc0045061e8b719db2d1df72efcd892d9940dc70))

- Solved clippy warning for remsol.rs and multilayer.rs
  ([`ac004af`](https://github.com/mpasson/REMSOL/commit/ac004af5667366a7ea978c2448673e432c9575bd))

### Testing

- Added benchmark for performance
  ([`2727e18`](https://github.com/mpasson/REMSOL/commit/2727e1898a8609ab521aa1ed9e89109d7c1e112a))


## v0.1.1 (2024-11-04)


## v0.1.0 (2024-10-13)


## v0.0.1 (2024-10-13)
